pub struct LocalePreferences {
pub(crate) language: Language,
pub(crate) script: Option<Script>,
pub(crate) region: Option<RegionalSubdivision>,
pub(crate) variant: Option<Variant>,
pub(crate) region_override: Option<RegionOverride>,
}Expand description
The structure storing locale subtags used in preferences.
Fields
language: LanguagePreference of Language
script: Option<Script>Preference of Script
region: Option<RegionalSubdivision>Preference of Region/Subdivision
variant: Option<Variant>Preference of Variant
region_override: Option<RegionOverride>Preference of Unicode region override
Implementations
Sourceimpl LocalePreferences
impl LocalePreferences
Sourcepub const fn to_data_locale_region_priority(self) -> DataLocale
pub const fn to_data_locale_region_priority(self) -> DataLocale
Convert to a DataLocale, with region-based fallback priority
Most users should use icu_provider::marker::make_locale() instead.
Sourcepub const fn to_data_locale_language_priority(self) -> DataLocale
pub const fn to_data_locale_language_priority(self) -> DataLocale
Convert to a DataLocale, with language-based fallback priority
Most users should use icu_provider::marker::make_locale() instead.
Sourceimpl LocalePreferences
impl LocalePreferences
Sourcepub const fn default() -> Self
pub const fn default() -> Self
Constructs a new LocalePreferences struct with the defaults.
Sourcepub fn from_locale_strict(loc: &Locale) -> Result<Self, Self>
pub fn from_locale_strict(loc: &Locale) -> Result<Self, Self>
Construct a LocalePreferences from a Locale
Returns Err if any of of the preference values are invalid.
Sourcepub const fn language(&self) -> Language
👎Deprecated since 2.2.0: convert to DataLocale to access fields
pub const fn language(&self) -> Language
convert to DataLocale to access fields
Preference of Language
Sourcepub const fn region(&self) -> Option<Region>
👎Deprecated since 2.2.0: convert to DataLocale to access fields
pub const fn region(&self) -> Option<Region>
convert to DataLocale to access fields
Preference of Region
Sourcepub fn extend(&mut self, other: LocalePreferences)
pub fn extend(&mut self, other: LocalePreferences)
Extends the preferences with the values from another set of preferences.